## django-reusable
`django-reusable` is a collection of common functionality needed in most Django projects.

### Pre-requisites
* Django >= 2.2
* django-tables2 >= 1.21.2
* django-crispy-forms >= 1.7.2
* pypugjs >= 5.6.0

### Installation
Install this package using pip

`pip install django-reusable`

Add the *django_reusable* to `INSTALLED_APPS`

```
INSTALLED_APPS += ("django_reusable", )
```

